Translations
============

If you want to help to translate this software please join me on Transifex: `transifex.com/projects/p/django-wp-admin/ <https://www.transifex.com/projects/p/django-wp-admin/>`_

Here is a list of available translations.

English
-------

Source (default) language.

Bulgarian
---------

Thanks to `Metodi Dejanov <https://www.transifex.com/accounts/profile/kpacn/>`_

Dutch (Netherlands)
-------------------

Thanks to `rico moorman <https://www.transifex.com/accounts/profile/rmoorman/>`_

French
------

Thanks to `qmarlats <https://www.transifex.com/accounts/profile/qmarlats/>`_

German
------

Thanks to `Silasoa <https://www.transifex.com/accounts/profile/Silasoa/>`_

Indonesian
----------

Thanks to `Al Firdaus <https://www.transifex.com/accounts/profile/alfirdaush/>`_

Italian
-------

Thanks to `Giuseppe Pignataro <https://www.transifex.com/accounts/profile/giuseppep/>`_

Polish
------

100% by me (Maciej 'barszcz' Marczewski)

Portuguese (Brazil)
-------------------

Thanks to `Kaio Henrique <https://www.transifex.com/accounts/profile/kaiobrito/>`_

Russian
-------

Thanks to `Eugene MechanisM <https://www.transifex.com/accounts/profile/MechanisM/>`_

